package com.ruoyi.aicall.service.impl;

import java.util.List;

import com.ruoyi.aicall.domain.CcAsrLanguages;
import com.ruoyi.aicall.mapper.CcAsrLanguagesMapper;
import com.ruoyi.aicall.service.ICcAsrLanguagesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.common.core.text.Convert;

/**
 * ASR语种及模型配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2026-04-08
 */
@Service
public class CcAsrLanguagesServiceImpl implements ICcAsrLanguagesService
{
    @Autowired
    private CcAsrLanguagesMapper ccAsrLanguagesMapper;

    /**
     * 查询ASR语种及模型配置
     * 
     * @param id ASR语种及模型配置主键
     * @return ASR语种及模型配置
     */
    @Override
    public CcAsrLanguages selectCcAsrLanguagesById(Long id)
    {
        return ccAsrLanguagesMapper.selectCcAsrLanguagesById(id);
    }

    /**
     * 查询ASR语种及模型配置列表
     * 
     * @param ccAsrLanguages ASR语种及模型配置
     * @return ASR语种及模型配置
     */
    @Override
    public List<CcAsrLanguages> selectCcAsrLanguagesList(CcAsrLanguages ccAsrLanguages)
    {
        return ccAsrLanguagesMapper.selectCcAsrLanguagesList(ccAsrLanguages);
    }

    /**
     * 新增ASR语种及模型配置
     * 
     * @param ccAsrLanguages ASR语种及模型配置
     * @return 结果
     */
    @Override
    public int insertCcAsrLanguages(CcAsrLanguages ccAsrLanguages)
    {
        return ccAsrLanguagesMapper.insertCcAsrLanguages(ccAsrLanguages);
    }

    /**
     * 修改ASR语种及模型配置
     * 
     * @param ccAsrLanguages ASR语种及模型配置
     * @return 结果
     */
    @Override
    public int updateCcAsrLanguages(CcAsrLanguages ccAsrLanguages)
    {
        return ccAsrLanguagesMapper.updateCcAsrLanguages(ccAsrLanguages);
    }

    /**
     * 批量删除ASR语种及模型配置
     * 
     * @param ids 需要删除的ASR语种及模型配置主键
     * @return 结果
     */
    @Override
    public int deleteCcAsrLanguagesByIds(String ids)
    {
        return ccAsrLanguagesMapper.deleteCcAsrLanguagesByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除ASR语种及模型配置信息
     * 
     * @param id ASR语种及模型配置主键
     * @return 结果
     */
    @Override
    public int deleteCcAsrLanguagesById(Long id)
    {
        return ccAsrLanguagesMapper.deleteCcAsrLanguagesById(id);
    }
}
